pub fn spawn_session_cleanup(state: SharedOAuthState)Expand description
Spawn a background task to periodically clean up revoked tokens.
pub fn spawn_session_cleanup(state: SharedOAuthState)Spawn a background task to periodically clean up revoked tokens.